/* ************************************************************** *
 *                                                                *
 * Copyright (c) 2005, Kota Mizushima, All rights reserved.       *
 *                                                                *
 *                                                                *
 * This software is distributed under the modified BSD License.   *
 * ************************************************************** */
package org.onion_lang.onion.compiler.utility;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

/**
 * @author Kota Mizushima
 * Date: 2005/09/15
 */
public class MethodInvoker {
  private MethodInvoker() {
  }
  
  public static Object call(Object target, String name, Object[] args)
  throws NoSuchMethodException, IllegalAccessException, InvocationTargetException {
    Class clazz = target.getClass();
    Method method = getMethod(clazz, name, args);
    return method.invoke(target, args);
  }
  
  public static Object callStatic(Class target, String name, Object[] args) 
  	throws NoSuchMethodException, IllegalAccessException, InvocationTargetException {
    Method method = getMethod(target, name, args);
    return method.invoke(null, args);
  }
  
  private static Method getMethod(Class target, String name, Object[] args)
  	throws NoSuchMethodException {
    Class[] argsClasses = new Class[args.length];
    for(int i = 0; i < args.length; i++) {
      argsClasses[i] = args[i].getClass();
    }
    return target.getMethod(name, argsClasses);    
  }
}
